<!-- markdownlint-disable MD007 -->
# BIDS

## Introduction

[**BIDS**](http://bids.neuroimaging.io/) (Brain Imaging Data Structure) is the standard adopted for the organisation
 of the datasets used by Clinica pipelines through the command line.
 BIDS provides a unified structure for organising and describing neuroimaging and behavioural data.
 The use of a standard like BIDS makes easier developing and distributing code that uses neuroimaging datasets.
 For this reason, when using Clinica pipelines from the command line, the input format of the dataset is required to be BIDS-compliant.

## An overview of the BIDS structure

Here is a general overview of the BIDS structure.
If you need more details, please check the [documentation](https://bids-specification.readthedocs.io/en/latest/) on the [website](http://bids.neuroimaging.io/).

```Text
BIDS_Dataset/
├── sub-CLNC01/
│   │   ├── ses-M00/
│   │   │   ├── anat/
│   │   │   │   ├── sub-CLNC01_ses-M00_T1w.json
│   │   │   │   └── sub-CLNC01_ses-M00_T1w.nii.gz
│   │   │   ├── dwi/
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.bval
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.bvec
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.json
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.nii.gz
│   │   │   │   └── ...
│   │   │   ├── fmap/
│   │   │   │   ├── sub-CLNC01_ses-M00_phasediff.json
│   │   │   │   ├── sub-CLNC01_ses-M00_phasediff.nii.gz
│   │   │   │   ├── sub-CLNC01_ses-M00_magnitude1.nii.gz
│   │   │   │   └── sub-CLNC01_ses-M00_magnitude2.nii.gz
│   │   │   ├── func/
│   │   │   │   ├── sub-CLNC01_ses-M00_task­-rest_bold.json
│   │   │   │   ├── sub-CLNC01_ses-M00_task­-rest_bold.nii.gz
│   │   │   │   └── ...
│   │   │   └── sub-CLNC01_ses-M00_scans.tsv
│   │   ├── ses-M18/
│   │   │   └── ...
│   │   └── sub-CLNC01_sessions.tsv
├── sub-CLNC02/
│   └── ...
├── ...
└── participants.tsv
```

## Validation of BIDS datasets

[bids-validator](https://github.com/bids-standard/bids-validator) can be run to ensure that a dataset is BIDS-compliant.

Clinica provides tools to curate several publicly available neuroimaging datasets ([ADNI](../Converters/ADNI2BIDS/), [AIBL](../Converters/AIBL2BIDS/), [NIFD](../Converters/NIFD2BIDS/) and [OASIS](../Converters/OASIS2BIDS/)) and convert them to BIDS.
We decided to ignore several warnings and errors detected by the validator.
These are listed in the `.bids-validator-config.json` and `.bidsignore` files at the root of each BIDS folder.
These files are automatically generated by Clinica converters to ignore the following issues:

- Won't fix errors:
    - PET modality is not officially supported by BIDS but is currently under revisions.
    See [BEP 009](https://github.com/bids-standard/bids-specification/pull/633) for details
    (`pet/` in `.bidsignore` / `SCANS_FILENAME_NOT_MATCH_DATASET` in `.bids-validator-config.json`).
    - All participants do not have the same sessions or modalities (`MISSING_SESSION` / `INCONSISTENT_SUBJECTS`).
    - JSON files with column description are not generated as TSV files already explicit the purpose of the
    columns in metadata files (`CUSTOM_COLUMN_WITHOUT_DESCRIPTION`).
    - The optional field `authors` is not filled in `dataset_description.json` (`NO_AUTHORS`).
    - The folder `conversion_info` is not BIDS-compliant (`conversion_info/` in `.bidsignore`).
- fMRI-specific: these errors are not fixed as there are no preprocessing pipelines for this modality in Clinica yet
(`SLICE_TIMING_NOT_DEFINED` / `NIFTI_PIXDIM4` / `BOLD_NOT_4D` / `REPETITION_TIME_MUST_DEFINE` / `TASK_NAME_MUST_DEFINE`).
- Probable DICOM errors (`NIFTI_UNIT` / `INCONSISTENT_PARAMETERS`).
